#! /usr/bin/python

import gi
gi.require_version('Gdk', '3.0')
gi.require_version('Gtk', '3.0')
from gi.repository import Gdk
from gi.repository import Gtk

Gdk.threads_init ()

import sys
import vlc

from gettext import gettext as _

# Create a single vlc.Instance() to be shared by (possible) multiple players.
if 'linux' in sys.platform:
    # Inform libvlc that Xlib is not initialized for threads
    instance = vlc.Instance("--no-xlib")
else:
    instance = vlc.Instance()

class VLCWidget(Gtk.DrawingArea):
    """Simple VLC widget.

    Its player can be controlled through the 'player' attribute, which
    is a vlc.MediaPlayer() instance.
    """
    __gtype_name__ = 'VLCWidget'

    def __init__(self, size, *p):
        Gtk.DrawingArea.__init__(self)
        self.player = instance.media_player_new()
        def handle_embed(*args):
            if sys.platform == 'win32':
                self.player.set_hwnd(self.get_window().get_handle())
            else:
                self.player.set_xwindow(self.get_window().get_xid())
            return True
        self.connect("realize", handle_embed)
        self.set_size_request(size[0], size[1])
        #self.set_size_request(320, 200)

class MultiVideoPlayer:
    def main(self, filenames):
        # Build main window
        window=Gtk.Window()
        mainbox=Gtk.VBox()
        videos=Gtk.HBox()

        window.add(mainbox)
        mainbox.add(videos)

        # Create VLC widgets
        for fname in filenames:
            #v = DecoratedVLCWidget()
            v = VLCWidget((320, 200))
            v.player.set_media(instance.media_new(fname))
	    #v.player.set_repeat(True)
            videos.add(v)

        # Create global toolbar
        tb = Gtk.Toolbar.new()

        def execute(b, methodname):
            """Execute the given method on all VLC widgets.
            """
            for v in videos.get_children():
                getattr(v.player, methodname)()
            return True

        for text, tooltip, iconname, callback, arg in (
            (_("Play"), _("Global play"), 'gtk-media-play', execute, "play"),
            (_("Pause"), _("Global pause"), 'gtk-media-pause', execute, "pause"),
            (_("Stop"), _("Global stop"), 'gtk-media-stop', execute, "stop"),
            (_("Quit"), _("Quit"), 'gtk-quit', Gtk.main_quit, None),
            ):
            i = Gtk.Image.new_from_icon_name(iconname, Gtk.IconSize.MENU)
            b = Gtk.ToolButton.new(i, text)
            b.set_tooltip_text(tooltip)
            b.connect("clicked", callback, arg)
            tb.insert(b, -1)

        mainbox.pack_start(tb, False, False, 0)

        window.show_all()
        window.connect("destroy", Gtk.main_quit)
	window.fullscreen()
        Gtk.main()

if __name__ == '__main__':
    if not sys.argv[1:]:
       print('You must provide at least 1 movie filename')
       sys.exit(1)
    if len(sys.argv[1:]) == 1:
        # Only 1 file. Simple interface
        p=VideoPlayer()
        from evaluator import Evaluator
        e = Evaluator(globals(), locals())
        e.popup()
        p.main(sys.argv[1])
    else:
        # Multiple files.
        p=MultiVideoPlayer()
        p.main(sys.argv[1:])
    instance.release()
